summaryrefslogtreecommitdiffstats
path: root/libkdepim/linklocator.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/linklocator.h')
-rw-r--r--libkdepim/linklocator.h28
1 files changed, 14 insertions, 14 deletions
diff --git a/libkdepim/linklocator.h b/libkdepim/linklocator.h
index 2c7fdbb1..6078fed1 100644
--- a/libkdepim/linklocator.h
+++ b/libkdepim/linklocator.h
@@ -23,8 +23,8 @@
#ifndef LINKLOCATOR_H_INCLUDED
#define LINKLOCATOR_H_INCLUDED
-#include <qstring.h>
-#include <qmap.h>
+#include <tqstring.h>
+#include <tqmap.h>
#include <kdepimmacros.h>
@@ -49,7 +49,7 @@ public:
* @param pos An index into 'text' from where the search
* should begin.
*/
- LinkLocator(const QString& text, int pos = 0);
+ LinkLocator(const TQString& text, int pos = 0);
/**
* Sets the maximum length of URLs that will be matched by
@@ -98,7 +98,7 @@ public:
*
* @return The URL at the current scan position, or an empty string.
*/
- QString getUrl();
+ TQString getUrl();
/**
* Attempts to grab an email address. If there is an @ symbol at the
@@ -111,7 +111,7 @@ public:
* @return The email address at the current scan position, or an empty
* string.
*/
- QString getEmailAddress();
+ TQString getEmailAddress();
/**
* Converts plaintext into html. The following characters are converted to HTML
@@ -136,7 +136,7 @@ public:
* @return An HTML version of the text supplied in the 'plainText' parameter,
* suitable for inclusion in the BODY of an HTML document.
*/
- static QString convertToHtml(const QString& plainText, int flags = 0,
+ static TQString convertToHtml(const TQString& plainText, int flags = 0,
int maxUrlLen = 4096, int maxAddressLen = 255);
static const int PreserveSpaces = 0x01;
@@ -146,15 +146,15 @@ public:
/** Embed the given PNG image into a data URL.
* @param iconPath path to the PNG image
* @return A data URL, QString::null if the image could not be read.
*/
- static QString pngToDataUrl( const QString & iconPath );
+ static TQString pngToDataUrl( const TQString & iconPath );
protected:
/**
* The plaintext string being scanned for URLs and email addresses.
*/
- QString mText;
+ TQString mText;
/**
* The current scan position.
*/
@@ -162,7 +162,7 @@ protected:
private:
bool atUrl() const;
- bool isEmptyUrl(const QString& url);
+ bool isEmptyUrl(const TQString& url);
/**
* Replaces smiley text with an <img> tag containing the relevant image.
@@ -170,20 +170,20 @@ private:
* "(^|\s+)text(\s+|$)"
* @return An HTML String with <img> for an emoticon
*/
- QString getEmoticon();
+ TQString getEmoticon();
/**
* Highlight text according to *bold*, /italic/ and _underlined_ markup.
* @return A HTML string.
*/
- QString highlightedText();
+ TQString highlightedText();
int mMaxUrlLen;
int mMaxAddressLen;
// maps the smiley text to the corresponding emoticon name
- static QMap<QString, QString> *s_smileyEmoticonNameMap;
+ static TQMap<TQString, TQString> *s_smileyEmoticonNameMap;
// cache for the HTML representation of a smiley
- static QMap<QString, QString> *s_smileyEmoticonHTMLCache;
+ static TQMap<TQString, TQString> *s_smileyEmoticonHTMLCache;
};
#endif // LINKLOCATOR_H_INCLUDED
@@ -146,15 +146,15 @@ public:
/** Embed the given PNG image into a data URL.
* @param iconPath path to the PNG image
- * @return A data URL, QString::null if the image could not be read.
+ * @return A data URL, TQString::null if the image could not be read.
*/